
#ifndef MOLEQUEUECLIENT_EXPORT_H
#define MOLEQUEUECLIENT_EXPORT_H

#ifdef MOLEQUEUECLIENT_STATIC_DEFINE
#  define MOLEQUEUECLIENT_EXPORT
#  define MOLEQUEUECLIENT_NO_EXPORT
#else
#  ifndef MOLEQUEUECLIENT_EXPORT
#    ifdef MoleQueueClient_EXPORTS
        /* We are building this library */
#      define MOLEQUEUECLIENT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define MOLEQUEUECLIENT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef MOLEQUEUECLIENT_NO_EXPORT
#    define MOLEQUEUECLIENT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef MOLEQUEUECLIENT_DEPRECATED
#  define MOLEQUEUECLIENT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MOLEQUEUECLIENT_DEPRECATED_EXPORT
#  define MOLEQUEUECLIENT_DEPRECATED_EXPORT MOLEQUEUECLIENT_EXPORT MOLEQUEUECLIENT_DEPRECATED
#endif

#ifndef MOLEQUEUECLIENT_DEPRECATED_NO_EXPORT
#  define MOLEQUEUECLIENT_DEPRECATED_NO_EXPORT MOLEQUEUECLIENT_NO_EXPORT MOLEQUEUECLIENT_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef MOLEQUEUECLIENT_NO_DEPRECATED
#    define MOLEQUEUECLIENT_NO_DEPRECATED
#  endif
#endif

#endif /* MOLEQUEUECLIENT_EXPORT_H */
